@@ -2,7 +2,7 @@ from django.conf import settings as django_settings
 from django.template import Library, Token, TOKEN_BLOCK, Node, Variable
 
 from netauth import settings as netauth_settings
-
+from netauth.models import NetID
 
 register = Library()
 
@@ -17,6 +17,19 @@ def option( value, name ):
     When django-misc app will be in PyPi, it will be removed from here
 """
 
+@register.simple_tag
+def get_providers(request):
+    netids = NetID.objects.filter(user=request.user)
+    providers = [netid.provider for netid in netids]
+    return providers
+
+@register.simple_tag
+def insert_sign(providers, provider):
+    if provider in providers:
+        return """<div class="social-provider-sign social-provider-check"></div>"""
+    else:
+        return """<div class="social-provider-sign social-provider-uncheck"></div>"""
+
 @register.tag
 def set(parser, token):
     """
