@@ -1,11 +1,12 @@
 from django.contrib import messages, auth
-from django.http import Http404
+from django.http import Http404, HttpResponseRedirect
 from django.shortcuts import render_to_response, redirect
 from django.template import RequestContext
 
 from netauth import settings, lang
 from netauth.utils import str_to_class, get_backend
 
+
 def logout(request):
     auth.logout(request)
     messages.success(request, lang.SUCCESS_LOGOUT)
@@ -13,7 +14,7 @@ def logout(request):
 
 
 def begin(request, provider):
-    """ 
+    """
         Display authentication form. This is also the first step
         in registration. The actual login is in social_complete
         function below.
@@ -28,7 +29,7 @@ def begin(request, provider):
 
 #redirect_decorator
 def complete(request, provider):
-    """ 
+    """
         After first step of net authentication, we must validate the response.
         If everything is ok, we must do the following:
         1. If user is already authenticated:
@@ -54,6 +55,8 @@ def complete(request, provider):
     backend = get_backend(provider)
     response = backend.validate(request, data)
 
+    if isinstance(response, HttpResponseRedirect):
+        return response
     if request.user.is_authenticated():
         success = backend.login_user(request)
         backend.merge_accounts(request)
@@ -67,13 +70,13 @@ def complete(request, provider):
     return backend.complete(request, response)
 
 def extra(request, provider):
-    """ 
+    """
         Handle registration of new user with extra data for profile
     """
     identity = request.session.get('identity', None)
     if not identity:
         raise Http404
-    
+
     if request.method == "POST":
         form = str_to_class(settings.EXTRA_FORM)(request.POST)
         if form.is_valid():
